fallbackDirections property
Fallback camera directions to try if the primary direction is not available
Implementation
final List<CameraLensDirection> fallbackDirections;
Fallback camera directions to try if the primary direction is not available
final List<CameraLensDirection> fallbackDirections;