pauseBlurAmount property
The amount of blur that is applied to the camera view when the camera is paused
Implementation
final double pauseBlurAmount;
The amount of blur that is applied to the camera view when the camera is paused
final double pauseBlurAmount;