pauseZoomAmount property
The amount of zoom that is applied to the camera view when the camera is paused
Implementation
final double pauseZoomAmount;
The amount of zoom that is applied to the camera view when the camera is paused
final double pauseZoomAmount;