BarcodeKitUiBuilder class abstract
A builder that is used to build the UI for the barcode kit
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildCameraNotAvailable(
BuildContext context) → Widget - Build the widget that is shown when the camera is not available
-
buildCameraNotOpened(
BuildContext context) → Widget - Build the widget that is shown when the camera is not opened yet
-
buildNoPermission(
BuildContext context, void onSettingsRequested()) → Widget - Build the widget that is shown when the user has not granted permission
-
buildRequestPermission(
BuildContext context, void onPermissionRequested()) → Widget - Build the widget that is shown when the user has not granted permission
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited