DetectedBarcode class
Constructors
-
DetectedBarcode({String? rawValue, List<
CornerPoint?> ? cornerPoints, BarcodeFormat? format, String? textValue})
Properties
-
cornerPoints
↔ List<
CornerPoint?> ? -
getter/setter pair
- format ↔ BarcodeFormat?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- rawValue ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textValue ↔ String?
-
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object result) → DetectedBarcode